@@ -6,7 +6,8 @@ __all__ = [
   'number',
   'either',
   'choice',
-  'member'
+  'member',
+  'seq'
 ]
 
 class boolean(object):
@@ -253,3 +254,16 @@ class member(object, metaclass=typing):
       current = getattr(current, item)
 
     return current
+
+
+class seq(object, metaclass=typing):
+  def __init__(self, t):
+    self.t = t
+
+  def __call__(self, value):
+    if not isinstance(value, (tuple, list)):
+      raise ValueError('seq only accepts tuples, got %s.' % (value, ))
+
+    return tuple(
+      self.t(v) for v in value
+    )
\ No newline at end of file
