@@ -9,7 +9,7 @@ __all__ = [
 ]
 
 def get_types(signature):
-  from .special import kwargs, args
+  from .special import kwargs
 
   types = dict()
 
@@ -27,17 +27,14 @@ def get_types(signature):
       else:
         annotation = type(parameter.default)
 
-    if annotation is None:
-      types[k] = None
-
-    elif not callable(annotation):
+    if not callable(annotation) and annotation is not None:
       raise ValueError('Annotation %s is not understood, must be absent or a callable.' % (annotation,))
 
-    elif parameter.kind == inspect.Parameter.VAR_KEYWORD:
-      types[k] = kwargs(annotation)
+    elif annotation is None and parameter.kind == inspect.Parameter.VAR_KEYWORD:
+      types[k] = kwargs()
 
-    elif parameter.kind == inspect.Parameter.VAR_POSITIONAL:
-      types[k] = args(annotation)
+    elif annotation is None:
+      types[k] = None
 
     elif annotation == bool:
       from .common import boolean
@@ -51,18 +48,33 @@ def get_types(signature):
 def bind(signature, types, *args, **kwargs):
   bound = signature.bind(*args, **kwargs)
 
+  ### applying defaults for *args and **kwargs
+  ### as they always have implicit defaults
+  ### and their presence is required for functionality of config.
+  var_keyword = [
+    p for p in signature.parameters
+    if signature.parameters[p].kind == inspect.Parameter.VAR_POSITIONAL
+  ]
+
+  for p in var_keyword:
+    if p not in bound.arguments:
+      bound.arguments[p] = tuple()
+
+  var_keyword = [
+    p for p in signature.parameters
+    if signature.parameters[p].kind == inspect.Parameter.VAR_KEYWORD
+  ]
+
+  for p in var_keyword:
+    if p not in bound.arguments:
+      bound.arguments[p] = dict()
+
   for arg in bound.arguments:
     cast = types.get(arg, None)
     value = bound.arguments[arg]
 
     if cast is None:
-      if signature.parameters[arg].kind == inspect.Parameter.VAR_KEYWORD:
-        pass
-      elif signature.parameters[arg].kind == inspect.Parameter.VAR_POSITIONAL:
-        pass
-      else:
-        import warnings
-        warnings.warn('No type is specified for parameter %s. Assuming string.' % (arg,))
+      pass
 
     elif type(arg) != str:
       ### already converted
@@ -233,6 +245,7 @@ def gearup(*args, **kwargs):
 
   return cli_commands(commands)
 
+
 class typing(type):
   def __getitem__(cls, item):
     if isinstance(item, tuple):
